==> blesta-5.10.2.zip: blesta/components/modules/direct_admin/language/ru_ru/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Статистическая информация в настоящее время отсутствует.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Значение';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Поле';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Информация';
$lang['DirectAdmin.tab_client_stats'] = 'Статистика';
$lang['DirectAdmin.edit_row.add_btn'] = 'Редактировать сервер';
$lang['DirectAdmin.edit_row.notes_title'] = 'Примечания';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Удалить';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Имя хоста';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Сервер имен';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Добавить дополнительный сервер имен';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Серверы имен';
$lang['DirectAdmin.edit_row.basic_title'] = 'Основные настройки';
$lang['DirectAdmin.edit_row.box_title'] = 'Редактирование сервера DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Добавить сервер';
$lang['DirectAdmin.add_row.notes_title'] = 'Примечания';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Удалить';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Имя хоста';
$lang['DirectAdmin.add_row.name_server_col'] = 'Сервер имен';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Добавить дополнительный сервер имен';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Серверы имен';
$lang['DirectAdmin.add_row.basic_title'] = 'Основные настройки';
$lang['DirectAdmin.add_row.box_title'] = 'Добавить сервер DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Сервер имен %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Лимит счета';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Используйте SSL при подключении к API (рекомендуется)';
$lang['DirectAdmin.row_meta.password'] = 'Пароль';
$lang['DirectAdmin.row_meta.user_name'] = 'Имя пользователя';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Порт';
$lang['DirectAdmin.row_meta.host_name'] = 'Имя хоста';
$lang['DirectAdmin.row_meta.server_name'] = 'Ярлык сервера';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Вы уверены, что хотите удалить эту группу серверов?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Вы уверены, что хотите удалить этот сервер?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Удалить';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Удалить';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Редактировать';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Редактировать';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Опции';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Количество серверов';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Название группы';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Опции';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Счета';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Имя хоста';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Ярлык сервера';
$lang['DirectAdmin.manage.module_groups_title'] = 'Группы серверов';
$lang['DirectAdmin.manage.module_rows_title'] = 'Серверы';
$lang['DirectAdmin.add_module_group'] = 'Добавить группу серверов';
$lang['DirectAdmin.add_module_row'] = 'Добавить сервер';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Назначить';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Общий';
$lang['DirectAdmin.package_fields.ip'] = 'IP-адрес';
$lang['DirectAdmin.package_fields.package'] = 'Пакет DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Реселлер';
$lang['DirectAdmin.package_fields.type_user'] = 'Пользователь';
$lang['DirectAdmin.package_fields.type'] = 'Тип счета';
$lang['DirectAdmin.service_info.option_login'] = 'Войти';
$lang['DirectAdmin.service_info.options'] = 'Опции';
$lang['DirectAdmin.service_info.server'] = 'Сервер';
$lang['DirectAdmin.service_info.password'] = 'Пароль';
$lang['DirectAdmin.service_info.username'] = 'Имя пользователя';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Сгенерировать пароль';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Обновить пароль';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Подтвердите пароль';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Пароль';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Изменить пароль';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Сгенерировать пароль';
$lang['DirectAdmin.service_field.email'] = 'Электронная почта';
$lang['DirectAdmin.service_field.password'] = 'Пароль';
$lang['DirectAdmin.service_field.username'] = 'Имя пользователя';
$lang['DirectAdmin.service_field.domain'] = 'Домен';
$lang['DirectAdmin.server_groups.no_results'] = 'Групп серверов не существует.';
$lang['DirectAdmin.servers.no_results'] = 'Здесь нет серверов.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Равномерное распределение между серверами';
$lang['DirectAdmin.order_options.first'] = 'Первый неполный сервер';
$lang['DirectAdmin.tab_client_actions'] = 'Действия';
$lang['DirectAdmin.tab_stats'] = 'Статистика';
$lang['DirectAdmin.module_group'] = 'Группа серверов';
$lang['DirectAdmin.module_row_plural'] = 'Серверы';
$lang['DirectAdmin.module_row'] = 'Сервер';
$lang['DirectAdmin.description'] = 'DirectAdmin - это графическая веб-панель управления хостингом, предназначенная для облегчения администрирования веб-сайтов.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Модуль не поддерживает изменение между пользовательскими и реселлерскими пакетами.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Пожалуйста, введите действительный адрес электронной почты.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Пароль и подтверждение пароля не совпадают.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Убедитесь, что пароль содержит следующее: Не менее 12 символов, не менее 1 символа в верхнем регистре A-Z, не менее 1 символа в нижнем регистре a-z, не менее 1 цифры 0-9 и не менее 1 специального символа из набора: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Имя пользователя должно содержать от 4 до 8 символов.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Имя пользователя может содержать только буквенно-цифровые символы.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Введите действительное доменное имя вида: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Необходимо указать IP-адрес.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Требуется пакет DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Тип учетной записи должен быть либо пользовательским, либо реселлером.';
$lang['DirectAdmin.!error.api.internal'] = 'Произошла внутренняя ошибка, или сервер не ответил на запрос.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Вы должны определить как минимум 2 сервера имен.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Один или несколько введенных серверов имен недействительны.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Account Limit можно оставить пустым (для неограниченных счетов) или установить целочисленное значение.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Use SSL должно быть либо true, либо false.';
$lang['DirectAdmin.!error.password.format'] = 'Вы должны ввести пароль.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Вы должны ввести имя пользователя.';
$lang['DirectAdmin.!error.port.format'] = 'Порт должен быть номером.';
$lang['DirectAdmin.!error.host_name.format'] = 'Похоже, что имя хоста недействительно.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Необходимо ввести метку сервера.';

==> blesta-5.11.4.zip: blesta/components/modules/direct_admin/language/ru_ru/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.ru_ru
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'Статистическая информация в настоящее время отсутствует.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Значение';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Поле';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Информация';
$lang['DirectAdmin.tab_client_stats'] = 'Статистика';
$lang['DirectAdmin.edit_row.add_btn'] = 'Редактировать сервер';
$lang['DirectAdmin.edit_row.notes_title'] = 'Примечания';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Удалить';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Имя хоста';
$lang['DirectAdmin.edit_row.name_server_col'] = 'Сервер имен';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Добавить дополнительный сервер имен';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'Серверы имен';
$lang['DirectAdmin.edit_row.basic_title'] = 'Основные настройки';
$lang['DirectAdmin.edit_row.box_title'] = 'Редактирование сервера DirectAdmin';
$lang['DirectAdmin.add_row.add_btn'] = 'Добавить сервер';
$lang['DirectAdmin.add_row.notes_title'] = 'Примечания';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Удалить';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Имя хоста';
$lang['DirectAdmin.add_row.name_server_col'] = 'Сервер имен';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Добавить дополнительный сервер имен';
$lang['DirectAdmin.add_row.name_servers_title'] = 'Серверы имен';
$lang['DirectAdmin.add_row.basic_title'] = 'Основные настройки';
$lang['DirectAdmin.add_row.box_title'] = 'Добавить сервер DirectAdmin';
$lang['DirectAdmin.row_meta.name_server'] = 'Сервер имен %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Лимит счета';
$lang['DirectAdmin.row_meta.use_ssl'] = 'Используйте SSL при подключении к API (рекомендуется)';
$lang['DirectAdmin.row_meta.password'] = 'Пароль';
$lang['DirectAdmin.row_meta.user_name'] = 'Имя пользователя';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Порт';
$lang['DirectAdmin.row_meta.host_name'] = 'Имя хоста';
$lang['DirectAdmin.row_meta.server_name'] = 'Ярлык сервера';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Вы уверены, что хотите удалить эту группу серверов?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Вы уверены, что хотите удалить этот сервер?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Удалить';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Удалить';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Редактировать';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Редактировать';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Опции';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Количество серверов';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Название группы';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Опции';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Счета';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Имя хоста';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Ярлык сервера';
$lang['DirectAdmin.manage.module_groups_title'] = 'Группы серверов';
$lang['DirectAdmin.manage.module_rows_title'] = 'Серверы';
$lang['DirectAdmin.add_module_group'] = 'Добавить группу серверов';
$lang['DirectAdmin.add_module_row'] = 'Добавить сервер';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Назначить';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Общий';
$lang['DirectAdmin.package_fields.ip'] = 'IP-адрес';
$lang['DirectAdmin.package_fields.package'] = 'Пакет DirectAdmin';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Реселлер';
$lang['DirectAdmin.package_fields.type_user'] = 'Пользователь';
$lang['DirectAdmin.package_fields.type'] = 'Тип счета';
$lang['DirectAdmin.service_info.option_login'] = 'Войти';
$lang['DirectAdmin.service_info.options'] = 'Опции';
$lang['DirectAdmin.service_info.server'] = 'Сервер';
$lang['DirectAdmin.service_info.password'] = 'Пароль';
$lang['DirectAdmin.service_info.username'] = 'Имя пользователя';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Сгенерировать пароль';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Обновить пароль';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Подтвердите пароль';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Пароль';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Изменить пароль';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Сгенерировать пароль';
$lang['DirectAdmin.service_field.email'] = 'Электронная почта';
$lang['DirectAdmin.service_field.password'] = 'Пароль';
$lang['DirectAdmin.service_field.username'] = 'Имя пользователя';
$lang['DirectAdmin.service_field.domain'] = 'Домен';
$lang['DirectAdmin.server_groups.no_results'] = 'Групп серверов не существует.';
$lang['DirectAdmin.servers.no_results'] = 'Здесь нет серверов.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Равномерное распределение между серверами';
$lang['DirectAdmin.order_options.first'] = 'Первый неполный сервер';
$lang['DirectAdmin.tab_client_actions'] = 'Действия';
$lang['DirectAdmin.tab_stats'] = 'Статистика';
$lang['DirectAdmin.module_group'] = 'Группа серверов';
$lang['DirectAdmin.module_row_plural'] = 'Серверы';
$lang['DirectAdmin.module_row'] = 'Сервер';
$lang['DirectAdmin.description'] = 'DirectAdmin - это графическая веб-панель управления хостингом, предназначенная для облегчения администрирования веб-сайтов.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.!error.change_package.type'] = 'Модуль не поддерживает изменение между пользовательскими и реселлерскими пакетами.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Пожалуйста, введите действительный адрес электронной почты.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Пароль и подтверждение пароля не совпадают.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Убедитесь, что пароль содержит следующее: Не менее 12 символов, не менее 1 символа в верхнем регистре A-Z, не менее 1 символа в нижнем регистре a-z, не менее 1 цифры 0-9 и не менее 1 специального символа из набора: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Имя пользователя должно содержать от 4 до 8 символов.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Имя пользователя может содержать только буквенно-цифровые символы.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Введите действительное доменное имя вида: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Необходимо указать IP-адрес.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Требуется пакет DirectAdmin.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Тип учетной записи должен быть либо пользовательским, либо реселлером.';
$lang['DirectAdmin.!error.api.internal'] = 'Произошла внутренняя ошибка, или сервер не ответил на запрос.';
$lang['DirectAdmin.!error.name_servers.count'] = 'Вы должны определить как минимум 2 сервера имен.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Один или несколько введенных серверов имен недействительны.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Account Limit можно оставить пустым (для неограниченных счетов) или установить целочисленное значение.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'Use SSL должно быть либо true, либо false.';
$lang['DirectAdmin.!error.password.format'] = 'Вы должны ввести пароль.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Вы должны ввести имя пользователя.';
$lang['DirectAdmin.!error.port.format'] = 'Порт должен быть номером.';
$lang['DirectAdmin.!error.host_name.format'] = 'Похоже, что имя хоста недействительно.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Необходимо ввести метку сервера.';
$lang['DirectAdmin.row_meta.ip_address'] = 'IP-адрес';
$lang['DirectAdmin.!error.ip_address.format'] = 'Похоже, что IP-адрес недействителен.';
